OwsCapabilities(version, updateSequence = NA, owsVersion = sosDefaultGetCapOwsVersion, identification = NULL, provider = NULL, operations = NULL, contents = NULL, languages = NULL)
OwsException(exceptionCode, exceptionText = c(), locator = as.character(NA))
OwsExceptionReport(version, lang = as.character(NA), exceptions = list(NA))
OwsGetCapabilities(service, acceptVersions, sections = sosDefaultGetCapSections, acceptFormats = sosDefaultGetCapAcceptFormats, updateSequence = c(as.character(NA)), owsVersion = sosDefaultGetCapOwsVersion, acceptLanguages = c(NA))
OwsOperation(name, DCPs, parameters = list(NA), constraints = list(NA), metadata = list(NA))
OwsOperationsMetadata(operations, parameters = list(NA), constraints = list(NA), extendedCapabilities = xmlNode(NA))
OwsRange(minimumValue = as.character(NA), maximumValue = as.character(NA), rangeClosure = as.character(NA), spacing = as.character(NA))
OwsServiceProvider(providerName, providerSite = as.character(NA), serviceContact = xmlNode(NA))
OwsServiceIdentification(serviceType, serviceTypeVersion, profile = c(NA), title, abstract = c(NA), keywords = c(NA), fees = as.character(NA), accessConstraints = c(NA))OwsContentsOrNULL.OwsExceptionsData.OwsException in a OwsExceptionReport.OwsExceptionsData.OwsServiceIdentificationOrNULL.XMLAbstractNode.OwsExceptionsData.OwsOperation in a OperationsMetadata object. The provider section of a capabilities document.OwsServiceProviderOrNULL.OwsCapabilities_1.1.0(...), OwsContents(...) or OwsException(...).The following classes are virtual and no objects may be created from it: OwsContentsOrNULL, OwsServiceIdentificationOrNULL, OwsServiceProviderOrNULL, OwsOperationsMetadataOrNULL.
"OwsCapabilities ", directly.OwsCapabilities_2.0.0:
Class ", directly.
Class ", by class "OwsCapabilities_1.1.0", distance 2.
OwsGetCapabilities_1.1.0
Class ", directly.
Class ", by class "OwsGetCapabilities", distance 2.
OwsGetCapabilities_2.0.0:
Class ", directly.
Class ", by class "OwsGetCapabilities_1.1.0", distance 2.
Class ", by class "OwsGetCapabilities_1.1.0", distance 3.
OwsServiceIdentification:
Class ", directly.
OwsServiceProvider:
Class ", directly.
OwsServiceOperation is the top class which is eventually put into the request method, sosRequest(...).Classes ending in
Whiteside A., Greenwood, J. (Eds.), OGC Web Services Common Standard, Open Geospatial Consortium Inc., OGC 06-121r9, Version: 2.0.0
showClass("OwsCapabilities_1.1.0")
showClass("OwsCapabilities_2.0.0")
showClass("OwsCapabilities")
showClass("OwsContents")
showClass("OwsContentsOrNULL")
showClass("OwsException")
showClass("OwsExceptionReport")
showClass("OwsGetCapabilities_1.1.0")
showClass("OwsGetCapabilities_2.0.0")
showClass("OwsGetCapabilities")
showClass("OwsOperation")
showClass("OwsOperationsMetadata")
showClass("OwsRange")
showClass("OwsServiceIdentification")
showClass("OwsServiceIdentificationOrNULL")
showClass("OwsServiceOperation")
showClass("OwsServiceProvider")
showClass("OwsServiceProviderOrNULL")
# TBD examples for construction functionsRun the code above in your browser using DataLab