SweCompositePhenomenon(id, name, description = as.character(NA), dimension,
components, base = NULL)
SwePhenomenon(id, name, description = as.character(NA))
SwePhenomenonProperty(href = as.character(NA), phenomenon = NULL)
SweTextBlock(tokenSeparator, blockSeparator, decimalSeparator,
id = as.character(NA))",".";".".".SweCompositePhenomenon( ...), SwePhenomenonProperty( ...) and so forth. The following classes are virtual, no objects may be created from them: SwePhenomenonOrNULL, SwePhenomenonPropertyOrNULL.dimension:"integer", the value of the dimensions attribute of a composite phenomenon.components:"list", the components of a composite phenomenon.base:"SwePhenomenonPropertyOrNULL", the base of a composite phenomenon, may be NULL.id:"character", the value of the id attribute of a (composite) phenomenon.name:"character", the value of the name element of a (composite) phenomenon.description:"character", the value of the description elements of a phenomenon.href:"character", the value of the href attribute of a phenomenon property which references a phenomenon.phenomenon:"SwePhenomenonOrNULL", the actual (inline) phenomenon of a phenomenon property.tokenSeparator:"character", the symbol to be used as the token seperator in a SweTextBlock, e.g. in the case of "," this would result in attribute1,attribute2.blockSeparator:"character", the symbol to be used as the block seperator in a SweTextBlock, e.g. in the case of ";" this would result in attribute1_a,attribute2_a;attribute1_b,attribute2_b.decimalSeparator:"character", the symbol to be used as the decimal seperator in a SweTextBlock, e.g. in the case of "." this would result in attribute1,42.0,attribute3,23.0."SwePhenomenon", directly.
Class "SwePhenomenonOrNULL", by class "SwePhenomenon", distance 2. SwePhenomenon:
Class "SwePhenomenonOrNULL", directly. SwePhenomenonProperty:
Class "SwePhenomenonPropertyOrNULL", directly.signature(object = "SweCompositePhenomenon"): ... signature(object = "SwePhenomenon"): ... signature(object = "SwePhenomenonProperty"): ... signature(object = "SweTextBlock"): ... ...OrNULL classes are used to model optional slots.
showClass("SweCompositePhenomenon")
showClass("SwePhenomenon")
showClass("SwePhenomenonProperty")
showClass("SwePhenomenonPropertyOrNULL")
showClass("SweTextBlock")
# TBD examples for construction functions
Run the code above in your browser using DataLab